==> jc-1.4.0.tar.gz: java/nio/channels/IllegalSelectorException.h <==
// public class java.nio.channels.IllegalSelectorException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 680cf34d05feb5a1 java_lang_IllegalArgumentException
// @dep_class 2a7152deee1944f1 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class da1b0f2a964ec0f2 java_nio_channels_IllegalSelectorException

// header file dependencies
// @dep_header java_lang_IllegalArgumentException

#include "java/lang/IllegalArgumentException.h"

#ifndef _JC_java_nio_channels_IllegalSelectorException_H_
#define _JC_java_nio_channels_IllegalSelectorException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_nio_channels_IllegalSelectorException$sub_refs	_jc_java_nio_channels_IllegalSelectorException$sub_refs;
typedef struct _jc_java_nio_channels_IllegalSelectorException$sub_nonrefs	_jc_java_nio_channels_IllegalSelectorException$sub_nonrefs;
typedef struct _jc_java_nio_channels_IllegalSelectorException$refs	_jc_java_nio_channels_IllegalSelectorException$refs;
typedef struct _jc_java_nio_channels_IllegalSelectorException$nonrefs	_jc_java_nio_channels_IllegalSelectorException$nonrefs;
typedef struct _jc_java_nio_channels_IllegalSelectorException$object	_jc_java_nio_channels_IllegalSelectorException$object;

typedef const struct _jc_java_nio_channels_IllegalSelectorException$vmethods	_jc_java_nio_channels_IllegalSelectorException$vmethods;
typedef const struct _jc_java_nio_channels_IllegalSelectorException$vtable	_jc_java_nio_channels_IllegalSelectorException$vtable;
typedef const struct _jc_java_nio_channels_IllegalSelectorException$vtype	_jc_java_nio_channels_IllegalSelectorException$vtype;

// Constructors
extern void _jc_java_nio_channels_IllegalSelectorException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_channels_IllegalSelectorException$object *);

// Virtual methods structure
struct _jc_java_nio_channels_IllegalSelectorException$vmethods {
};

// Vtable
struct _jc_java_nio_channels_IllegalSelectorException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_IllegalArgumentException$vmethods	java_lang_IllegalArgumentException;
	_jc_java_nio_channels_IllegalSelectorException$vmethods	java_nio_channels_IllegalSelectorException;
};

// Vtype
struct _jc_java_nio_channels_IllegalSelectorException$vtype {
	_jc_type			type;
	_jc_java_nio_channels_IllegalSelectorException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_IllegalSelectorException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_IllegalSelectorException$refs {
    _jc_java_nio_channels_IllegalSelectorException$sub_refs	java_nio_channels_IllegalSelectorException;
    _jc_java_lang_IllegalArgumentException$sub_refs	java_lang_IllegalArgumentException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_IllegalSelectorException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_IllegalSelectorException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_IllegalArgumentException$sub_nonrefs	java_lang_IllegalArgumentException;
    _jc_java_nio_channels_IllegalSelectorException$sub_nonrefs	java_nio_channels_IllegalSelectorException;
};

// Object instance structure
struct _jc_java_nio_channels_IllegalSelectorException$object {
	_jc_java_nio_channels_IllegalSelectorException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_IllegalSelectorException$vtype	*vtype;
	_jc_java_nio_channels_IllegalSelectorException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_IllegalSelectorException$vtype _jc_java_nio_channels_IllegalSelectorException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_IllegalSelectorException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_IllegalSelectorException$class_object;

#endif	/* _JC_java_nio_channels_IllegalSelectorException_H_ */

==> jc-1.4.6.tar.gz: java/nio/channels/IllegalSelectorException.h <==
// public class java.nio.channels.IllegalSelectorException

// class file dependencies
// @dep_class c5feb325780a6cd7 java_lang_Exception
// @dep_class 680cf34d05feb5a1 java_lang_IllegalArgumentException
// @dep_class 1c4f1fc002fc96e5 java_lang_Object
// @dep_class 4f5534a987354d1d java_lang_RuntimeException
// @dep_class 3be5c3c4fdd59a1e java_lang_Throwable
// @dep_class da1b0f2a964ec0f2 java_nio_channels_IllegalSelectorException

// header file dependencies
// @dep_header java_lang_IllegalArgumentException

#include "java/lang/IllegalArgumentException.h"

#ifndef _JC_java_nio_channels_IllegalSelectorException_H_
#define _JC_java_nio_channels_IllegalSelectorException_H_

// Forward structure declarations
struct _jc_java_lang_Class$object;

// Typedefs
typedef struct _jc_java_nio_channels_IllegalSelectorException$sub_refs	_jc_java_nio_channels_IllegalSelectorException$sub_refs;
typedef struct _jc_java_nio_channels_IllegalSelectorException$sub_nonrefs	_jc_java_nio_channels_IllegalSelectorException$sub_nonrefs;
typedef struct _jc_java_nio_channels_IllegalSelectorException$refs	_jc_java_nio_channels_IllegalSelectorException$refs;
typedef struct _jc_java_nio_channels_IllegalSelectorException$nonrefs	_jc_java_nio_channels_IllegalSelectorException$nonrefs;
typedef struct _jc_java_nio_channels_IllegalSelectorException$object	_jc_java_nio_channels_IllegalSelectorException$object;

typedef const struct _jc_java_nio_channels_IllegalSelectorException$vmethods	_jc_java_nio_channels_IllegalSelectorException$vmethods;
typedef const struct _jc_java_nio_channels_IllegalSelectorException$vtable	_jc_java_nio_channels_IllegalSelectorException$vtable;
typedef const struct _jc_java_nio_channels_IllegalSelectorException$vtype	_jc_java_nio_channels_IllegalSelectorException$vtype;

// Constructors
extern void _jc_java_nio_channels_IllegalSelectorException$method$_init$52f4ad9f2989aeee(_jc_env *, struct _jc_java_nio_channels_IllegalSelectorException$object *) _JC_JCNI_ATTR;

// Virtual methods structure
struct _jc_java_nio_channels_IllegalSelectorException$vmethods {
};

// Vtable
struct _jc_java_nio_channels_IllegalSelectorException$vtable {
	_jc_java_lang_Object$vmethods	java_lang_Object;
	_jc_java_lang_Throwable$vmethods	java_lang_Throwable;
	_jc_java_lang_Exception$vmethods	java_lang_Exception;
	_jc_java_lang_RuntimeException$vmethods	java_lang_RuntimeException;
	_jc_java_lang_IllegalArgumentException$vmethods	java_lang_IllegalArgumentException;
	_jc_java_nio_channels_IllegalSelectorException$vmethods	java_nio_channels_IllegalSelectorException;
};

// Vtype
struct _jc_java_nio_channels_IllegalSelectorException$vtype {
	_jc_type			type;
	_jc_java_nio_channels_IllegalSelectorException$vtable	vtable;
};

// Reference instance fields (subclass)
struct _jc_java_nio_channels_IllegalSelectorException$sub_refs {
};

// Reference instance fields (object)
struct _jc_java_nio_channels_IllegalSelectorException$refs {
    _jc_java_nio_channels_IllegalSelectorException$sub_refs	java_nio_channels_IllegalSelectorException;
    _jc_java_lang_IllegalArgumentException$sub_refs	java_lang_IllegalArgumentException;
    _jc_java_lang_RuntimeException$sub_refs	java_lang_RuntimeException;
    _jc_java_lang_Exception$sub_refs	java_lang_Exception;
    _jc_java_lang_Throwable$sub_refs	java_lang_Throwable;
    _jc_java_lang_Object$sub_refs	java_lang_Object;
};

// Non-reference instance fields (subclass)
struct _jc_java_nio_channels_IllegalSelectorException$sub_nonrefs {
};

// Non-reference instance fields (object)
struct _jc_java_nio_channels_IllegalSelectorException$nonrefs {
    _jc_java_lang_Object$sub_nonrefs	java_lang_Object;
    _jc_java_lang_Throwable$sub_nonrefs	java_lang_Throwable;
    _jc_java_lang_Exception$sub_nonrefs	java_lang_Exception;
    _jc_java_lang_RuntimeException$sub_nonrefs	java_lang_RuntimeException;
    _jc_java_lang_IllegalArgumentException$sub_nonrefs	java_lang_IllegalArgumentException;
    _jc_java_nio_channels_IllegalSelectorException$sub_nonrefs	java_nio_channels_IllegalSelectorException;
};

// Object instance structure
struct _jc_java_nio_channels_IllegalSelectorException$object {
	_jc_java_nio_channels_IllegalSelectorException$refs	refs[0];
	_jc_word		lockword;
	_jc_java_nio_channels_IllegalSelectorException$vtype	*vtype;
	_jc_java_nio_channels_IllegalSelectorException$nonrefs	nonrefs;
};

// Type structure
extern _jc_java_nio_channels_IllegalSelectorException$vtype _jc_java_nio_channels_IllegalSelectorException$type;

// Array types class info structures
_JC_DECL_ARRAYS(java_nio_channels_IllegalSelectorException, type);

// java.lang.Class instance
extern struct _jc_java_lang_Class$object _jc_java_nio_channels_IllegalSelectorException$class_object;

#endif	/* _JC_java_nio_channels_IllegalSelectorException_H_ */
